use clap::Subcommand;

use super::CliError;

#[derive(Subcommand)]
pub enum Command {
    /// Add devices of a specific user to the same sync group
    Sync {
        username: String,
        devices: Vec<String>,
    },
    /// List the devices for the given user
    Devices { username: String },
}

impl Command {
    pub fn run(&self, config: &crate::config::Config) -> Result<(), CliError> {
        let store =
            gpodder_sqlite::SqliteRepository::from_path(config.data_dir.join(crate::DB_FILENAME))
                .map_err(|err| CliError::from(err).msg("failed to initialize Sqlite repository"))?;
        let store = gpodder::GpodderRepository::new(store);

        match self {
            Self::Sync { username, devices } => {
                let user = store.get_user(username)?;
                store.update_device_sync_status(
                    &user,
                    vec![devices.iter().map(|s| s.as_ref()).collect()],
                    Vec::new(),
                )?;
            }
            Self::Devices { username } => {
                let user = store.get_user(username)?;
                let devices = store.devices_for_user(&user)?;

                for device in devices {
                    println!("{} ({} subscriptions)", device.id, device.subscriptions);
                }
            }
        }

        Ok(())
    }
}
