use std::path::PathBuf;

use clap::ValueEnum;
use serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize, Clone, ValueEnum, Copy, Debug)]
#[serde(rename_all = "lowercase")]
pub enum LogLevel {
    Debug,
    Info,
    Warn,
    Error,
}

impl From<LogLevel> for tracing::Level {
    fn from(value: LogLevel) -> Self {
        match value {
            LogLevel::Debug => Self::DEBUG,
            LogLevel::Info => Self::INFO,
            LogLevel::Warn => Self::WARN,
            LogLevel::Error => Self::ERROR,
        }
    }
}

#[derive(Serialize, Deserialize)]
#[serde(rename_all = "lowercase")]
#[serde(tag = "type")]
pub enum NetConfig {
    Tcp { domain: String, port: u16 },
    Unix { path: PathBuf },
}

#[derive(Serialize, Deserialize)]
pub struct Config {
    pub net: NetConfig,
    pub data_dir: PathBuf,
    pub session_cleanup_interval: u64,
    pub log_level: LogLevel,
}

impl Default for Config {
    fn default() -> Self {
        Self {
            net: NetConfig::Tcp {
                domain: "127.0.0.1".to_string(),
                port: 8080,
            },
            data_dir: "./data".into(),
            // Once per day
            session_cleanup_interval: 60 * 60 * 24,
            log_level: LogLevel::Warn,
        }
    }
}
